# Internationalization

### ConfigProvider

antd-mobile provides a Component [ConfigProvider](../components/config-provider) for configuring antd locale text globally.

```jsx
import { ConfigProvider } from "antd-mobile";
import enUS from 'antd-mobile/es/locales/en-US'

return (
  <ConfigProvider locale={enUS}>
    <App />
  </ConfigProvider>
)
```

The following languages are currently supported: | Language | Filename | |-----------------------|----------| | Chinese (Simplified) | zh-CN | | Chinese (Traditional) | zh-HK | | Chinese (Traditional) | zh-TW | | English | en-US | | Persian | fa-IR | | Spanish | es-ES | | Korean | ko-KR | | Japanese | ja-JP | | Kazakh | kk-KZ | | Indonesian | id-ID |

See more usage at [ConfigProvider](../components/config-provider).

### Add new language

If your language is not above list, welcome to create a locale package based on the [en-US](https://github.com/ant-design/ant-design-mobile/blob/master/src/locales/en-US.ts) lanugage pack and send us a Pull Request. [language code table](http://www.lingoes.net/en/translator/langcode.htm)

Do it step by step:

1. Add a locale file in `src/locales`.
2. Add a test case for the language in [config-provider.test.tsx](https://github.com/ant-design/ant-design-mobile/blob/master/src/components/config-provider/tests/config-provider.test.tsx).
3. Run `pnpm test -u` command to update the snapshots.
4. (Optional) Add the language to i18n list [i18n.zh.md](https://github.com/ant-design/ant-design-mobile/blob/master/docs/guide/i18n.zh.md) 和 [i18n.en.md](https://github.com/ant-design/ant-design-mobile/blob/master/docs/guide/i18n.en.md).

## FAQ

### Why the ConfigProvider not work when component used in an imperative way?

Taking the Modal component as an example, antd-mobile will dynamic create React instance by `ReactDOM.render` when you call `Modal.show`. Whose context is different with origin code located context.

You can set the default language through `setDefaultConfig`

```jsx
import { setDefaultConfig } from 'antd-mobile'

setDefaultConfig({
  locale: enUS,
})
```
